from setuptools import setup

setup(name='pyeon',
      version='0.0.1',
      description='''Generates some phrases when someone goes to the\
convenience store.''',
      url='http://github.com/qria/pyeon',
      author='MinJune Kim',
      author_email='qria' '@' 'qria.net',
      license='MIT',
      packages=['pyeon'],
      zip_safe=False)
